@@ -28,7 +28,7 @@ def service_client(url, timeout=(5, 5), http_adapter=None, before_request=None):
     return wrapper
 
 
-def service_mapping(uri, method, dest_type=None):
+def service_mapping(uri, method):
     def wrapper(f):
         try:
             is_method = inspect.getargspec(f)[0][0] == 'self'
@@ -50,13 +50,13 @@ def service_mapping(uri, method, dest_type=None):
                 data = kwargs.get('data', None)
             client = service_endpoint[name]
             if method == HTTP_METHOD_GET:
-                return client.get(_uri, params=data, dest_type=dest_type)
+                return client.get(_uri, params=data)
             elif method == HTTP_METHOD_POST:
-                return client.post(_uri, json_data=data, dest_type=dest_type)
+                return client.post(_uri, json_data=data)
             elif method == HTTP_METHOD_PUT:
-                return client.put(_uri, json_data=data, dest_type=dest_type)
+                return client.put(_uri, json_data=data)
             elif method == HTTP_METHOD_DELETE:
-                return client.delete(_uri, dest_type=dest_type)
+                return client.delete(_uri)
             else:
                 raise Exception('{}.{} is invalid method', f.__module__, f.__name__)
 
